AttributionResult class
Result of POST /v1/sdk/attribution/launch.
Constructors
- AttributionResult({required bool matched, String? qaClid, String? campaignId, String? templateId, String? variantId})
-
Creates a result snapshot.
const
-
AttributionResult.fromJson(Map<
String, dynamic> json) -
Decode from API JSON.
factory
Properties
- campaignId → String?
-
Resolved campaign id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matched → bool
-
Whether a campaign click was successfully attributed to this launch.
final
- qaClid → String?
-
QuickAuth click identifier echoed back. Persisted so future conversions
can be tied to the same click.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateId → String?
-
Resolved template id.
final
- variantId → String?
-
Resolved A/B variant id.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited